@@ -11,12 +11,12 @@ use vars qw($VERSION @ISA);
 our @ISA = qw(Exporter);
 # the EXPORT_OK and EXPORT_TAGS is code by [kcott] @ Perlmongs.org, thanks!
 # see https://perlmonks.org/?node_id=11115288
-our (@EXPORT_OK, %EXPORT_TAGS);
+our (@EXPORT);
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 BEGIN {
-	$VERSION = '0.03';
+	$VERSION = '0.04';
 	if ($] > 5.006) {
 		require XSLoader;
 		XSLoader::load(__PACKAGE__, $VERSION);
@@ -25,12 +25,8 @@ BEGIN {
 		@ISA = qw(DynaLoader);
 		__PACKAGE__->bootstrap;
 	}
-	@EXPORT_OK = qw/generate_random_strings/;
-	%EXPORT_TAGS = (
-		# the :all tag: so we can use this like
-		#  use String::Random::Regexp::regxstring qw/:all/;
-		all => [@EXPORT_OK]
-	);
+        # export these by default:
+	@EXPORT = qw/generate_random_strings/;
 }
 
 # $regx is a string containing a regular expression
@@ -75,7 +71,7 @@ String::Random::Regexp::regxstring - Generate random strings from a regular expr
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =head1 SYNOPSIS
 
